Learn R Programming

CITAN (version 2011.04-1)

dbBiblioConnect: Connect to a local bibliometric storage driven by SQLite

Description

Connects to a local bibliometric storage handled by SQLite engine (see RSQLite package documentation).

Usage

dbBiblioConnect(dbfilename)

Arguments

dbfilename
name of the file storing the SQLite database.

Value

  • An object of type SQLiteConnection. It is used to direct commands to the SQLite engine.

Details

Do not forget to close the connection (represented by the object returned) with dbDisconnect after use. Note that you may freely access the database using functions from the DBI package called on the returned connection object.

See Also

dbBiblioCreate, dbDisconnect

Examples

Run this code
con <- dbBiblioConnect("Bibliometrics.db");
## ...
dbDisconnect(con);

Run the code above in your browser using DataLab