Scopus_ReadCSV.dbBiblioImportDocuments(con, data, surveyDescription="Default survey",
originalFilename=attr(data, "filename"), excludeRows,
updateDocumentIfExists=TRUE, doVacuum=TRUE, warnISSN=FALSE,
warnExactDuplicates=FALSE, warnDuplicateTitles=TRUE, verbose=TRUE)dbBiblioConnect.data.frame with bibliometric entries; see above.attr(data, "filename") is used by default.data to exclude or NULLTRUE, then documents with the same UniqueId will be updated.TRUE then the SQL command VACUUM
will be executed on the database after importing data to optimize and compact the bibliometric storage.TRUE then warnings are generated if a given ISSN in not found in the table Biblio_Sources.TRUE to warn if exact duplicates are found (turned off by default).TRUE to warn if documents
of the same Title but different UniqueIds are found.
This may indicate possible data misrepresentations.TRUE to print out the progress of lengthy computations.TRUE on success.data must consist of the following 14 columns (in order). Otherwise
the process will not be executed.
Authors character Author(s) name(s), comma-separated, surnames first.
2 Title character Document title.
3 Year numeric Year of publication.
4 SourceTitle character Title of the source containing the document.
5 Volume character Volume.
6 Issue character Issue.
7 ArticleNumber character Article number (identifier).
8 PageStart numeric Start page; numeric.
9 PageEnd numeric End page; numeric.
10 Citations numeric Number of citations.
11 UniqueId character Unique document identifier. Documents with is.na(UniqueId) will not be added.
12 ISSN character ISSN of the source.
13 Language factor Language of the document.
14 DocumentType factor Type of the document; NA (other categories are interpreted as NA).
}Note that if data contains many records (>1000),
the import process may take a few minutes.
Sources (e.g. journals) are identified by ISSNs (table Biblio_Sources).
Note that generally there is no need to concern about missing ISSNs of
conference proceedings.
Each time a function is called, a new record in the table Biblio_Surveys
is created. Such surveys may be grouped using the Description
field, see dbBiblioCreate.
Scopus_ReadCSV, dbBiblioConnect, dbBiblioCreatecon <- dbBiblioConnect("Bibliometrics.db");
## ...
data <- Scopus_ReadCSV("db_Polish_MATH/Poland_MATH_1987-1993.csv");
dbBiblioImportDocuments(con, data, "Poland_MATH");
## ...
dbDisconnect(con);Run the code above in your browser using DataLab