index.g(x, sorted.dec=FALSE, disable.check=FALSE)TRUE if the vector has already been sorted non-increasingly; defaults FALSE.TRUE to disable some validity checks on the input vector; defaults FALSE.If disable.check is set to FALSE, then
eventual NA values are removed from the input vector.
If a non-increasingly sorted vector is given as input (set sorted.dec to TRUE)
the value is calculated in linear time.
index.h, index.rp, index.lp, Sstat, Sstat2