Usage
lbsSearchDocuments(conn, titles.like = NULL, idAuthors = NULL,
citations.expr = NULL, pages.expr = NULL, year.expr = NULL,
documentTypes = NULL, alternativeId = NULL, surveyDescription = NULL)
Arguments
titles.like
character vector of SQL-LIKE patterns to match documents' titles or NULL.
idAuthors
numeric or integer vector with author identifiers (see column IdAuthor in the table Biblio_Authors) or NULL.
citations.expr
expression determining the desired number of citations or NULL, see Examples below.
pages.expr
expression determining the desired number of pages or NULL, see Examples below.
year.expr
expression determining the desired publication year or NULL, see Examples below.
documentTypes
character vector or NULL; specifies document types to restrict to;
a combination of Article, Article in Press, Book, Conference Paper,
Editorial, Erratum, Let
alternativeId
character vector of documents' AlternativeIds.
surveyDescription
single character string or NULL; survey description to restrict to or NULL.