pareto2.htest.approx(x, y, s, alternative=c("two.sided", "less",
"greater"), significance)significance$<1$ or="" NULL. See Value for details.1$>$significance is not NULL, then
the list of class power.htest with the following components is passed as a result:
statistic the value of the test statistic.
result either FALSE (accept null hypothesis) or TRUE (reject).
alternative a character string describing the alternative hypothesis.
method a character string indicating what type of test was performed.
data.name a character string giving the name(s) of the data.
}
Otherwise, the list of class htest with the following components is passed as a result:
statistic the value of the test statistic.
p.value the p-value of the test.
alternative a character string describing the alternative hypothesis.
method a character string indicating what type of test was performed.
data.name a character string giving the name(s) of the data.
}alternative.
It bases on a test statistic that is a function of {H(Y)-H(X)},
where $H$ denotes Hirsch's $h$-index (see index.h).
This statistic approximately has asymptotically standardized normal distribution under $H_0$.Note that for $k_x < k_y$, then $X$ dominates $Y$ stochastically.
dpareto2, pareto2.goftest, pareto2.ftest, pareto2.htest, index.h