Fair and objective assessment methods of individual scientists had become the focus of scientometricians' attention since the very beginning of their discipline. A quantitative expression of some publication-citation process characteristics is assumed to be a predictor of broadly conceived scientific competence.
Among the most popular scientific impact indicators is the $h$-index, proposed by J. Hirsch (2005). It has been defined as follows. An author who had published $n$ papers has the Hirsch index equal to $H$, if each of his $H$ publications were cited at least $H$ times, and each of the other $n-H$ items were cited no more than $H$ times. This simple bibliometric indicator quickly received much attention in the academic community and started to be a subject of intensive research. It was noted that contrary to earlier approaches, i.e. publication count, citation count etc., this measure both concerns productivity and impact of an individual.
In a broader perspective, this issue is a special case of the so-called Producer Assessment Problem (Gagolewski, Grzegorzewski, 2010b). Its main aim is to analyze (both theoretically and empirically) a special class of aggregation operators (see Grabisch et al, 2009) called impact functions.
The CITAN package consists of three types of tools. Given a numeric vector, the first class of functions computes the values of certain impact functions. Among them are:
index.h),index.g),index.rpandindex.lp), which
generalize the$h$-index and the$w$-index (Woeginger, 2008), andSstatandSstat2),
which generalize the OWMax operators (Dubois et al, 1988)
and the$h$- and$r_\infty$-indices.Additionally, a set of functions dealing with stochastic aspects of the class of S-statistics and the Pareto type-II family of distributions is included (Gagolewski, Grzegorzewski, 2010a). We have the following. The functions that work for any continuous distribution (see Gagolewski, Grzegorzewski, 2010a):
psstat,dsstatfor computing the distribution of S-statistics
generated by a control function,phirsch,dhirschfor computing the distribution of the Hirsch index,rho.getfor computing the so-called$\kappa$-index ($\rho_\kappa$),
which is a particular location characteristic of a given probability distribution
depending on a control function$\kappa$.ppareto2,dpareto2,qpareto2,rpareto2for general functions dealing with the Pareto distribution of the second kind,
including the c.d.f., p.d.f, quantiles and random deviates,pareto2.htest--- two-sample$h$-test for equality of shape parameters based on the difference of$h$-indices,pareto2.ftest--- two-sample exact F-test for equality of shape parameters,pareto2.zsestimate--- estimation of parameters using the Bayesian method (MMSE) developed by Zhang and Stevens (2009),pareto2.goftest--- goodness-of-fit tests,pareto2.confint.rhoandpareto2.confint.rho.approx--- exact and approximate (asymptotic)
confidence intervals for the$\kappa$-index basing on S-statistics,pareto2.confint.h--- exact confidence intervals for the theoretical$h$-index.Moreover, we have implemented some simple graphical methods than may be used
to illustrate various aspects of data being analyzed,
see plot.citfun, curve.add.rp, and curve.add.lp.
Please feel free to send any comments and suggestions (e.g. to include some new bibliometric impact indices) to the author.
For a complete list of functions, use library(help="CITAN").